<template>
  <div class="bbsl-common-page">
    <div class="bbsl-btn-content" ref="btnPanel">
      <el-button icon="el-icon-plus" type="primary" @click="AddAttribute">新增
      </el-button>
      <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
        <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
          style="margin-left: 10px">删除
        </el-button>
      </el-popconfirm>
      <el-button style="margin-left: 10px" icon="el-icon-sort" @click="savePropertyf">保存排序号
      </el-button>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <el-table border size="mini" :data="tableData" :height="tableMaxHeight" :style="{ width: '100%' }"
        :cell-style="{ 'text-align': 'center' }" :header-cell-style="{ 'text-align': 'center' }"
        @row-dblclick="handleDbClick" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column type="index" width="55" label="序号"></el-table-column>
        <el-table-column prop="code" label="事件标识"></el-table-column>
        <el-table-column prop="name" label="事件名称"></el-table-column>
        <el-table-column prop="outDataTypeName" label="输出参数类型"></el-table-column>
        <el-table-column prop="outDataUnitName" label="输出参数单位"></el-table-column>
        <el-table-column prop="typeName" label="事件等级"></el-table-column>
        <el-table-column prop="memo" label="备注"></el-table-column>
        <el-table-column prop="sn" label="排序" show-overflow-tooltip>
          <template slot-scope="scope">
            <el-input type="number" size="small" min="1" @input="insort(scope.row)" v-model="scope.row.sn">
            </el-input>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background ref="paginationPanel" @size-change="handleSizeChange"
        @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
        :total="total"></el-pagination>
    </div>
    <EventDefinitionDialog ref="formModal" :productId="productIds" @reload="loadData"></EventDefinitionDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import PhysicalModel from '@/api/device/PhysicalModel.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import EventDefinitionDialog from './EventDefinitionDialog.vue'

export default {
  props: {
    parameterData: {
      type: Object,
      default: function () {
        return
      }
    }
  },
  mixins: [TableMixin],
  components: {
    EventDefinitionDialog
  },
  data() {
    return {
      url: {
        delete: '/device/metadata/events/'
      },
      productIds: '',
      typeList: [], //事件等级
      outDataFormartList: [], //参数格式
      outDataTypeList: [], //参数类型
      dataUnits: [],
      sortList: {}
    }
  },
  created() {
    this.typeList = dictUtils.getDictItemsFromCache('sjdj')
    this.outDataTypeList = dictUtils.getDictItemsFromCache('sxlx')
    // 数据单位
    this.dataUnits = dictUtils.getDictItemsFromCache('sjdw')
    this.productIds = this.parameterData.id
  },
  methods: {
    AddAttribute() {
      this.$refs.formModal.add()
    },
    loadData(page) {
      this.loading = true
      this.queryParam.querys = [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'productId',
          relation: 'AND',
          value: this.parameterData.id
        }
      ]
      PhysicalModel.loadEventDefinition(this.queryParam, res => {
        this.total = res.total
        res.rows.sort((a, b) => {
          return a.sn - b.sn
        })
        this.tableData = res.rows
        this.tableData.forEach(e => {
          this.typeList.forEach(t => {
            if (t.value == e.type) {
              e.typeName = t.name
            }
          })
          this.dataUnits.forEach(f => {
            if (f.value == e.outDataUnit) {
              e.outDataUnitName = f.name
            }
          })
          this.outDataTypeList.forEach(x => {
            if (x.value == e.outDataType) {
              e.outDataTypeName = x.name
            }
          })
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    insort(val) {
      console.log(val)
      let id = val.id
      let value = val.sn
      this.sortList[id] = value
    },
    savePropertyf() {
      PhysicalModel.saveProperty(this.sortList, res => {
        if (res.state) {
          this.$notify({
            type: 'success',
            message: res.message,
            duration: 2000
          })
          this.loadData()
        } else {
          this.$message.warning(res.message)
        }
      })
    },
    handleDeleteone() {
      console.log(1)
      console.log(this.multipleSelection)
    }
  }
}
</script>
<style lang="scss" scoped>
::v-deep .el-table {
  height: 100% !important;
}

::v-deep .bbsl-table-content {
  box-shadow: 0px 0px 0 0;
  margin-top: 0px;
  padding: 0px;
}

.bbsl-common-page {
  height: calc(100% - 10px);
}
</style>
